>From ec828d82bba41b8fcc649528ac77660e59395c46 Mon Sep 17 00:00:00 2001
From: Joseph Tulou <brezhoneg1@yahoo.fr>
Date: Tue, 27 Jan 2009 14:55:53 +0100
Subject: [PATCH] restriction on changing scaling at run time
changing scaling at run-time may not be compatible with certain vout-filter (e.g wall). It is therefore deactivated when vout-filter is used.
---
 src/video_output/vout_intf.c |   10 ++++++++++
 1 files changed, 10 insertions(+), 0 deletions(-)

diff --git a/src/video_output/vout_intf.c b/src/video_output/vout_intf.c
index 89cc527..40ba4c3 100644
--- a/src/video_output/vout_intf.c
+++ b/src/video_output/vout_intf.c
@@ -1215,6 +1215,14 @@ static int ScalingCallback( vlc_object_t *p_this, char const *psz_cmd,
 {
     vout_thread_t *p_vout = (vout_thread_t *)p_this;
 
+    /* Don't change scaling when working with vout-filter (prone to crash) */
+    char *psz_vout_filter = var_GetString( p_vout, "vout-filter" );
+    if( psz_vout_filter && *psz_vout_filter )
+    {
+        free( psz_vout_filter );
+        return VLC_SUCCESS;
+    }
+
     vlc_mutex_lock( &p_vout->change_lock );
 
     p_vout->b_scale = newval.b_bool;
@@ -1222,6 +1230,8 @@ static int ScalingCallback( vlc_object_t *p_this, char const *psz_cmd,
 
     vlc_mutex_unlock( &p_vout->change_lock );
 
+    if( psz_vout_filter )
+        free( psz_vout_filter );
     return VLC_SUCCESS;
 }
 
-- 
1.5.2.5

